@@ -8,4 +8,4 @@ from django.template.utils import get_app_template_dirs
 
 class Loader(FilesystemLoader):
     def get_dirs(self):
-        return get_app_template_dirs('components')
+        return get_app_template_dirs("components")
